==> kadu_0.5.0.orig.tar.gz: kadu/modules/default_sms/translations/default_sms_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>SMS Era Gateway</source>
        <translation>SMS EraGSM Gateway</translation>
    </message>
    <message>
        <source>Type of gateway</source>
        <translation>Tipo di Gateway</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>User ID (39xxxxxxxxx)</translation>
    </message>
</context>
<context>
    <name>SmsEraGateway</name>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La pagina dei risultati del Gateway dell&apos;operatore GSM sembra sconosciuta. SMS probabilmente NON trasmesso.</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Errore:</translation>
    </message>
    <message>
        <source>No error</source>
        <translation>Nessun errore</translation>
    </message>
    <message>
        <source>System failure</source>
        <translation>Guasto del sistema</translation>
    </message>
    <message>
        <source>Unauthorised user</source>
        <translation>Utente non autorizzato</translation>
    </message>
    <message>
        <source>Access forbidden</source>
        <translation>Accesso proibito</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>Errore di sintassi</translation>
    </message>
    <message>
        <source>Limit of the sms run-down</source>
        <translation>limite quantitativo SMS raggiunto</translation>
    </message>
    <message>
        <source>Message too long</source>
        <translation>Messaggio troppo lungo</translation>
    </message>
    <message>
        <source>Wrong receiver address</source>
        <translation>Indirizzo destinatario errato</translation>
    </message>
    <message>
        <source>Unknown error (%1)</source>
        <translation>Errore sconosciuto (%1)</translation>
    </message>
    <message>
        <source>You don&apos;t have enough tokens</source>
        <translation>Non hai sufficente quantita crediti</translation>
    </message>
    <message>
        <source>Number of SMS&apos; left on Sponsored Era Gateway: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsGatewaySlots</name>
    <message>
        <source>Sponsored</source>
        <translation>Sponsorizzata</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
</context>
<context>
    <name>SmsOrangeGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>La pagina del Gateway del fornitore sembra sconosciuta.
Probabilmente è temporaneamente disabilitata, o sono state cambiate le regole d&apos;accesso.</translation>
    </message>
    <message>
        <source>You exceeded your daily limit</source>
        <translation>Avete superato il vostro limite quotidiano di SMS inviati</translation>
    </message>
    <message>
        <source>Text from the picture is incorrect</source>
        <translation>Il testo d&apos;immagine errato</translation>
    </message>
    <message>
        <source>The receiver has to enable SMS STANDARD service</source>
        <translation>Il ricevente deve consentire (attivare) il servizio di STANDARD SMS</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La pagina dei risultati del Gateway dell&apos;operatore GSM sembra sconosciuta. SMS probabilmente NON trasmesso.</translation>
    </message>
</context>
<context>
    <name>SmsPlusGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>La pagina del Gateway del operatore GSM sembra sconosciuta.
Probabilmente è temporaneamente disattivata, o sono state cambiate le reole accesso.</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La pagina dei risultati del Gateway del operatore GSM sembra sconosciuta. SMS probabilmente NON trasmesso.</translation>
    </message>
    <message>
        <source>Limits have been exceeded, try again later.</source>
        <translation>I limiti sono stati raggiunti, riprova più tardi.</translation>
    </message>
</context>
</TS>

==> kadu_0.6.0.orig.tar.gz: kadu/modules/default_sms/translations/default_sms_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="4"/>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="8"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="12"/>
        <source>Gateways</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="15"/>
        <source>SMS Era Gateway</source>
        <translation>SMS Era Gateway</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="18"/>
        <source>Sponsored</source>
        <translation>Sponsorizzata</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="21"/>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="31"/>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>User ID (39xxxxxxxxx)</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="34"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>SmsEraGateway</name>
    <message>
        <location filename="../default_sms.cpp" line="344"/>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La pagina dei risultati del Gateway dell&apos;operatore GSM sembra sconosciuta. SMS probabilmente NON trasmesso.</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="340"/>
        <source>Error: </source>
        <translation>Errore:</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="353"/>
        <source>No error</source>
        <translation>Nessun errore</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="354"/>
        <source>System failure</source>
        <translation>Guasto del sistema</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="355"/>
        <source>Unauthorised user</source>
        <translation>Utente non autorizzato</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="356"/>
        <source>Access forbidden</source>
        <translation>Accesso proibito</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="357"/>
        <source>Syntax error</source>
        <translation>Errore di sintassi</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="358"/>
        <source>Limit of the sms run-down</source>
        <translation>limite quantitativo SMS raggiunto</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="360"/>
        <source>Message too long</source>
        <translation>Messaggio troppo lungo</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="359"/>
        <source>Wrong receiver address</source>
        <translation>Indirizzo destinatario errato</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="363"/>
        <source>Unknown error (%1)</source>
        <translation>Errore sconosciuto (%1)</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="361"/>
        <source>You don&apos;t have enough tokens</source>
        <translation>Non hai sufficente quantita crediti</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="333"/>
        <source>Number of SMS&apos; left on Sponsored Era Gateway: </source>
        <translation>Numero dei SMS lasciati a Era Gateway Sponsorizzato:</translation>
    </message>
</context>
<context>
    <name>SmsOrangeGateway</name>
    <message>
        <location filename="../default_sms.cpp" line="105"/>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>La pagina del Gateway del fornitore sembra sconosciuta.
Probabilmente è temporaneamente disabilitata, o sono state cambiate le regole d&apos;accesso.</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="130"/>
        <source>You exceeded your daily limit</source>
        <translation>Avete superato il vostro limite quotidiano di SMS inviati</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="136"/>
        <source>Text from the picture is incorrect</source>
        <translation>Il testo d&apos;immagine errato</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="142"/>
        <source>The receiver has to enable SMS STANDARD service</source>
        <translation>Il ricevente deve consentire (attivare) il servizio di STANDARD SMS</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="153"/>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La pagina dei risultati del Gateway dell&apos;operatore GSM sembra sconosciuta. SMS probabilmente NON trasmesso.</translation>
    </message>
</context>
<context>
    <name>SmsPlusGateway</name>
    <message>
        <location filename="../default_sms.cpp" line="234"/>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>La pagina del Gateway del operatore GSM sembra sconosciuta.
Probabilmente è temporaneamente disattivata, o sono state cambiate le reole accesso.</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="259"/>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La pagina dei risultati del Gateway del operatore GSM sembra sconosciuta. SMS probabilmente NON trasmesso.</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="252"/>
        <source>Limits have been exceeded, try again later.</source>
        <translation>I limiti sono stati raggiunti, riprova più tardi.</translation>
    </message>
</context>
</TS>
